@@ -16,3 +16,6 @@ FIEL_SIGNER = loc["FIEL_SIGNER"]
 EMISOR = loc["EMISOR"]
 EMAIL_MANAGER = loc["EMAIL_MANAGER"]
 FACTURAS_SOURCE = loc["FACTURAS_SOURCE"]
+PROPIETARIO_CORREO = loc["PROPIETARIO_CORREO"]
+AJUSTES_DIR = loc.get("AJUSTES_DIR", "ajustes")
+CORREO_FIRMA = loc["PROPIETARIO_CORREO"]
