@@ -1,5 +1,7 @@
 import logging
+import uuid
 from datetime import datetime
+from uuid import UUID
 
 from satcfdi.create.cfd import cfdi40
 from satcfdi.create.cfd.cfdi40 import Comprobante
@@ -43,6 +45,12 @@ def create_cfdi(factura_details, serie, folio):
         logger.error(f"{factura_details['Rfc']}: FormaPago '{invoice['FormaPago']}' is invalid, expected '99' for PPD")
         return None
 
+    for c in factura_details["Conceptos"]:
+        mes_ajuste = c.get("_MesAjusteAnual")
+        if not isinstance(mes_ajuste, int) or not (12 >= mes_ajuste >= 1):
+            logger.error(f"{factura_details['Rfc']}: No Tiene Mes de Ajuste Anual Valido")
+            return None
+
     return invoice
 
 
@@ -69,28 +77,50 @@ def generate_ingresos(values):
 
 def find_factura(factura):
     if not factura:
-        logger.error("Especificar factura a pagar")
+        logger.error("Factura No Especificada")
         return
 
+    try:
+        factura_uuid = uuid.UUID(factura)
+    except:
+        factura_uuid = None
+
     all_invoices = get_all_cfdi()
     for i in all_invoices.values():
-        if i.name == factura and i["Emisor"]["Rfc"] == EMISOR.rfc:
+        if (i.name == factura or i.uuid == factura_uuid) and i["Emisor"]["Rfc"] == EMISOR.rfc:
             logger.info(f"Factura Encontrada: {i['Receptor']['Rfc']}  {i.name}  {i.uuid}  {i['Fecha']}")
             return i
 
     logger.info(f"Factura No Encontrada {factura}")
 
 
-def pago_factura(factura_pagar, fecha_pago, forma_pago):
-    fecha_pago = datetime.fromisoformat(fecha_pago).replace(hour=12)
+def parse_fecha_pago(fecha_pago):
+    if not fecha_pago:
+        logger.error("Fecha de Pago esta vacia")
+        return
+
+    fecha_pago = datetime.fromisoformat(fecha_pago)
+    if fecha_pago > datetime.now():
+        logger.error("Fecha de Pago esta en el futuro")
+        return
+
+    if fecha_pago.replace(hour=12) > datetime.now():
+        fecha_pago = datetime.now()
+    else:
+        fecha_pago = fecha_pago.replace(hour=12)
 
     dif = datetime.now() - fecha_pago
     if dif.days > 30:
-        logger.error("Fecha de Pago es de hace mas de 30 dias")
+        logger.error("!!! FECHA DE PAGO ES MAYOR A 30 DIAS !!!")
+
+    return fecha_pago
+
+
+def pago_factura(factura_pagar, fecha_pago, forma_pago):
+    if not (fecha_pago := parse_fecha_pago(fecha_pago)):
         return
 
-    i = find_factura(factura_pagar)
-    if i:
+    if i := find_factura(factura_pagar):
         if i["TipoDeComprobante"] != "I":
             logger.error("Comprobante a pagar no es de Ingreso")
             return
@@ -104,6 +134,10 @@ def pago_factura(factura_pagar, fecha_pago, forma_pago):
             logger.error(f"Saldo Pendiente: {i.saldo_pendiente}")
             return
 
+        if i.estatus != "1":
+            logger.error("Comprobante ya esta cancelado")
+            return
+
         return generar_pago(cfdi=i, fecha_pago=fecha_pago, forma_pago=forma_pago)
 
 
